package es.uca.xmleye.presentation;

/*
 Copyright (C) 2005-2008 Antonio García Domínguez

 This program is free software; you can redistribute it 
 and/or modify it under the terms of the GNU General Public 
 License as published by the Free Software Foundation; 
 either version 2 of the License, or (at your option) any 
 later version.

 This program is distributed in the hope that it will be 
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE. See the GNU General Public License for more 
 details.

 You should have received a copy of the GNU General Public 
 License along with this program; if not, write to the Free 
 Software Foundation, Inc., 59 Temple Place, Suite 330, 
 Boston, MA 02111-1307 USA
 */

import java.util.Collections;
import java.util.List;
import java.util.ArrayList;

import es.uca.xmleye.prefs.PreferencesManager;

/**
 * RecentDocumentHistory de documentos recientes, guardado en las preferencias del usuario.
 */
public class RecentDocumentHistory {

	// Número máximo de elementos del historial de documentos recientes
	private final static int HISTORIAL_MAX_LONG = 5;
	// Clave de la preferencia de tipo lista que almacena el historial
	private final static String PREF_HISTORIAL = "@recent-docs";
	private PreferencesManager prefs;

	public RecentDocumentHistory(PreferencesManager prefs) {
		this.prefs = prefs;
	}

	/**
	 * Obtiene los elementos del historial de documentos recientes.
	 * 
	 * @return Vector con los nombres de fichero del historial.
	 */
	public List<String> getHistorial() {
		final List<String> hist = prefs.getListPref(PREF_HISTORIAL);
		return Collections.unmodifiableList(hist != null ? hist
				: new ArrayList<String>());
	}

	/**
	 * Añade un elemento al historial de documentos recientes.
	 * 
	 * @param ruta
	 *            Ruta completa al fichero a añadir.
	 */
	public void agregar(String ruta) {
		List<String> history = prefs.getListPref(PREF_HISTORIAL);
		if (history == null) {
			history = new ArrayList<String>();
			prefs.setListPref(PREF_HISTORIAL, history);
		}

		int indiceAntiguo = history.indexOf(ruta);
		if (indiceAntiguo != -1) {
			/*
			 * El fichero ya está en el historial: lo quitamos y lo ponemos como
			 * el más reciente
			 */
			history.remove(indiceAntiguo);
		}

		while (history.size() >= HISTORIAL_MAX_LONG) {
			history.remove(0);
		}
		history.add(ruta);
	}

	/**
	 * Retira un elemento del historial de documentos recientes.
	 * 
	 * @param ruta
	 *            Ruta completa al fichero que se va a retirar.
	 */
	public void retirar(String ruta) {
		List<String> history = prefs.getListPref(PREF_HISTORIAL);
		if (history == null)
			return;
		history.remove(ruta);
	}

}
