package es.uca.xmleye.xslt;

/*
 Copyright (C) 2008 Antonio García Domínguez

 This program is free software; you can redistribute it 
 and/or modify it under the terms of the GNU General Public 
 License as published by the Free Software Foundation; 
 either version 2 of the License, or (at your option) any 
 later version.

 This program is distributed in the hope that it will be 
 useful, but WITHOUT ANY WARRANTY; without even the implied 
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE. See the GNU General Public License for more 
 details.

 You should have received a copy of the GNU General Public 
 License along with this program; if not, write to the Free 
 Software Foundation, Inc., 59 Temple Place, Suite 330, 
 Boston, MA 02111-1307 USA

 */

import java.io.*;
import org.w3c.dom.*;
import javax.xml.transform.*;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;

/**
 * Stylesheet de visualización del nodo seleccionado.
 */
public class ViewStylesheet extends Stylesheet {
	// / UID del elemento siendo visualizado
	private String uidSeleccionado = "";

	// / Nombre lógico de la hoja
	private String nombre;

	/* --- CONSTRUCTORES --- */

	/**
	 * Crea una nueva hoja, usando el resolvedor por defecto.
	 */
	ViewStylesheet(String pRutaXSLT, String pNombre) {
		super(pRutaXSLT);
		this.nombre = pNombre;
	}

	/**
	 * Crea una nueva hoja, con un resolvedor personalizado.
	 */
	ViewStylesheet(String pRutaXSLT, URIResolver pResolvedorURI,
			String pNombre) {
		super(pRutaXSLT, pResolvedorURI);
		this.nombre = pNombre;
	}

	/* --- METODOS PUBLICOS --- */

	/**
	 * Obtiene el elemento actualmente seleccionado.
	 */
	public String getUIDSeleccionado() {
		return this.uidSeleccionado;
	}

	/**
	 * Cambia el elemento actualmente seleccionado.
	 */
	public void setUIDSeleccionado(String nuevoUID) {
		this.uidSeleccionado = nuevoUID;
	}

	/**
	 * Devuelve el nombre lógico de la hoja.
	 */
	public String getNombre() {
		return this.nombre;
	}

	/**
	 * Transforma el elemento <code>obj</code> del árbol <code>raiz</code> a
	 * su representación XHTML.
	 * 
	 * @param raiz
	 *            Raíz del árbol a transofmrar.
	 * @param obj
	 *            Nodo seleccionado del árbol.
	 * @return Salida XHTML a mostrar, o <code>null</code> si ha habido algún
	 *         fallo en la transformación.
	 */
	public String generarXHTML(Element elemSel, Document doc)
			throws TransformationException {
		setUIDSeleccionado(elemSel.getAttribute("UID"));

		final StringWriter sWriter = new StringWriter();
		transformar(new DOMSource(doc), new StreamResult(sWriter));

		return sWriter.toString();
	}

	/* --- METODOS PROTEGIDOS --- */

	@Override
	protected void configurarTransformador(Transformer trans)
			throws TransformerConfigurationException {
		trans.setParameter("selectedUID", uidSeleccionado);
	}
}
